==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/user/messages/ru/base.php <==
<?php

return [
    '<strong>Followers</strong>' => 'Подписавшиеся:',
    '<strong>Following</strong>' => 'Подписан(а) на:',
    '<strong>Member</strong> in these spaces' => '<strong>Участник</strong> этих сообществ',
    '<strong>Member</strong> of these Spaces' => '<strong>Участник</strong> сообществ',
    '<strong>People</strong>' => '<strong>Люди</strong>',
    '<strong>User</strong> tags' => 'Теги пользователя',
    'All' => 'Все',
    'Allow users to mention you' => 'Разрешить пользователям упоминать вас',
    'Allows access to your about page with personal information' => 'Предоставляет доступ к Вашей странице с личной информацией',
    'Any' => 'Любой',
    'Auth Mode' => 'Режим аутентификации',
    'Basic Settings' => 'Основные настройки',
    'Block user' => 'Заблокировать пользователя',
    'Change Email' => 'Изменить email',
    'Change Password' => 'Изменить пароль',
    'Change Username' => 'Измененить Имя пользователя',
    'Confirm new password' => 'Подтвердите новый пароль',
    'Connect account' => 'Подключиться к учётной записи',
    'Connected Accounts' => 'Подключенные учётные записи',
    'Connected accounts' => 'Подключенные учётные записи',
    'Created at' => 'Создано в',
    'Created by' => 'Создано пользователем',
    'Current password' => 'Текущий пароль',
    'Currently in use' => 'В настоящее время используется',
    'Default Group' => 'Группа по умолчанию',
    'Default Space' => 'Сообщество по умолчанию',
    'Delete' => 'Удалить',
    'Delete Account' => 'Удалить учётную запись',
    'Description' => 'Описание',
    'Did you forget your password?' => 'Забыли пароль?',
    'Disconnect account' => 'Отключить учётную запись',
    'Edit' => 'Изменить',
    'Email' => 'Email',
    'Enable Notifications' => 'Включить уведомления',
    'Find people by their profile data or user tags' => 'Находите людей по данным их профиля или тегам',
    'Follow' => 'Подписаться',
    'Followers' => 'Подписчики',
    'Following' => 'Подписан(а)',
    'Following (User)' => 'Подписан(а) (на пользователя)',
    'Force password change upon first login' => 'Обязать сменить пароль при первом входе',
    'Force password change upon next login' => 'Обязать сменить пароль при следующем входе',
    'Friends' => 'Друзья',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Здесь Вы можете подключиться к внешнему сервису для использования внешних служб, таких как единый вход в системах аутентификации.',
    'If this wasn\'t you, you can disregard this message.' => 'Если это не вы, можете не обращать внимания на это сообщение.',
    'Invite by email' => 'Пригласить с помощью электронной почты',
    'Invite by link' => 'Пригласить по ссылке',
    'Invite new people' => 'Приглашайте новых пользователей',
    'Invited by' => 'Приглашен(ы)',
    'It looks like you clicked on an invalid password reset link. Please try again.' => 'Похоже, вы нажали на недействительную ссылку для сброса пароля. Попробуйте ещё раз.',
    'Language' => 'Язык',
    'Last Login' => 'Последний вход',
    'Mentioning' => 'Упомянут(а)',
    'Missing E-Mail Attribute from AuthClient.' => 'Отсутствует атрибут Email от AuthClient.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Отсутствует атрибут ID AuthClient от AuthClient.',
    'Modules' => 'Модули',
    'My Account' => 'Моя учётная запись',
    'Name' => 'Имя',
    'New password' => 'Новый пароль',
    'No results found!' => 'Результатов не найдено!',
    'No users found.' => 'Пользователи не найдены.',
    'Notifications' => 'Уведомления',
    'Offline' => 'Оффлайн',
    'Online' => 'Онлайн',
    'Password' => 'Пароль',
    'Password changed' => 'Пароль изменен',
    'Password needs to be at least {chars} characters long.' => 'Длина пароля должна быть не менее {chars} символов.',
    'Password recovery' => 'Восстановление пароля',
    'Pending Requests' => 'Текущие запросы',
    'People' => 'Люди',
    'Permission' => 'Разрешение',
    'Profile' => 'Профиль',
    'Profile posts only' => 'Только посты пользователя',
    'Register now and participate!' => 'Зарегистрируйтесь сейчас',
    'Search...' => 'Поиск...',
    'Security' => 'Безопасность',
    'Settings' => 'Настройки',
    'Show At Registration' => 'Показать при Регистрации',
    'Show all content' => 'Показать все содержимое',
    'Sign in' => 'Войти',
    'Sign in / up' => 'Войти / Присоединиться',
    'Sign up' => 'Зарегистрироваться',
    'Sign up now' => 'Зарегистрироваться сейчас',
    'Sort order' => 'Порядок сортировки',
    'Source' => 'Источник',
    'Status' => 'Статус',
    'Tags' => 'Теги',
    'The secure link has been copied in your clipboard!' => 'Защищенная ссылка скопирована в буфер обмена!',
    'The user has been blocked for you.' => 'Пользователь был заблокирован для вас.',
    'The user has been unblocked for you.' => 'Пользователь был разблокирован для вас.',
    'Try other keywords or remove filters.' => 'Попробуйте другие ключевые слова или удалите фильтры.',
    'Unblock user' => 'Разблокировать пользователя',
    'Unknown user status!' => 'Неизвестный статус пользователья!',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Ошибок ввода пароля после последнего входа: {failedLoginAttemptsCount}',
    'Updated at' => 'Обновлено',
    'Updated by' => 'Обновлено пользователем',
    'User' => 'Пользователь',
    'User Group' => 'Группа пользователей',
    'User has been invited.' => 'Пользователь был приглашён.',
    'Username' => 'Имя пользователя',
    'Username contains invalid characters.' => 'Имя пользователя содержит недопустимые символы.',
    'View your about page' => 'Просмотр Вашей страницы «Обо мне»',
    'Visibility' => 'Отображение',
    'Visible' => 'Видимо',
    'Welcome to %appName%' => 'Добро пожаловать в %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Добро пожаловать в %appName%. Пожалуйста, нажмите на кнопку ниже, чтобы продолжить регистрацию.',
    'Whenever a user follows another user.' => 'Когда пользователь подписывается на другого пользователя.',
    'You got an invite' => 'Вы получили приглашение',
    'You tried registering an account with %appName%, but already have an account associated with this email address.' => 'Вы пытались зарегистрировать учетную запись в %appName%, но у вас уже есть учётная запись, связанная с этим адресом электронной почты.',
    'You\'re not registered.' => 'Вы не зарегистрированы.',
    'You\'ve been invited to join {space} on {appName}' => 'Вас пригласили присоединиться к сообществу {space} в {appName}',
    'Your account is disabled!' => 'Ваш аккаунт отключен!',
    'Your account is not approved yet!' => 'Ваш аккаунт еще не подтвержден!',
    'Your are already logged in! - Logout first!' => 'Вы уже вошли! - Сначала выйдите из системы!',
    'Your new password must not be equal your current password!' => 'Ваш новый пароль не должен совпадать с Вашим текущим паролем!',
    'invited you to join {name}.' => 'приглашает Вас присоединиться к {name}.',
    'invited you to join {space} on {name}.' => 'приглашает Вас присоединиться к сообществу {space} на {name}',
    'or' => 'или',
    'Advanced Profile Search' => '',
    'Group Manager(s)' => '',
    'The Group Manager can approve pending registrations of this group.' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/user/messages/ru/base.php <==
<?php

return [
    '<strong>Followers</strong>' => 'Подписавшиеся:',
    '<strong>Following</strong>' => 'Подписан(а) на:',
    '<strong>Member</strong> in these spaces' => '<strong>Участник</strong> этих сообществ',
    '<strong>Member</strong> of these Spaces' => '<strong>Участник</strong> сообществ',
    '<strong>People</strong>' => '<strong>Люди</strong>',
    '<strong>User</strong> tags' => 'Теги пользователя',
    'Advanced Profile Search' => 'Расширенный поиск в профилях',
    'All' => 'Все',
    'Allow users to mention you' => 'Разрешить пользователям упоминать вас',
    'Allows access to your about page with personal information' => 'Предоставляет доступ к Вашей странице с личной информацией',
    'Any' => 'Любой',
    'Auth Mode' => 'Режим аутентификации',
    'Basic Settings' => 'Основные настройки',
    'Block user' => 'Заблокировать пользователя',
    'Change Email' => 'Изменить email',
    'Change Password' => 'Изменить пароль',
    'Change Username' => 'Измененить Имя пользователя',
    'Confirm new password' => 'Подтвердите новый пароль',
    'Connect account' => 'Подключиться к учётной записи',
    'Connected Accounts' => 'Подключенные учётные записи',
    'Connected accounts' => 'Подключенные учётные записи',
    'Created at' => 'Создано в',
    'Created by' => 'Создано пользователем',
    'Current password' => 'Текущий пароль',
    'Currently in use' => 'В настоящее время используется',
    'Default Group' => 'Группа по умолчанию',
    'Default Space' => 'Сообщество по умолчанию',
    'Delete' => 'Удалить',
    'Delete Account' => 'Удалить учётную запись',
    'Description' => 'Описание',
    'Did you forget your password?' => 'Забыли пароль?',
    'Disconnect account' => 'Отключить учётную запись',
    'Edit' => 'Изменить',
    'Email' => 'Email',
    'Enable Notifications' => 'Включить уведомления',
    'Find people by their profile data or user tags' => 'Находите людей по данным их профиля или тегам',
    'Follow' => 'Подписаться',
    'Followers' => 'Подписчики',
    'Following' => 'Подписан(а)',
    'Following (User)' => 'Подписан(а) (на пользователя)',
    'Force password change upon first login' => 'Обязать сменить пароль при первом входе',
    'Force password change upon next login' => 'Обязать сменить пароль при следующем входе',
    'Friends' => 'Друзья',
    'Group Manager(s)' => 'Менеджер(ы) группы',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Здесь Вы можете подключиться к внешнему сервису для использования внешних служб, таких как единый вход в системах аутентификации.',
    'If this wasn\'t you, you can disregard this message.' => 'Если это не вы, можете не обращать внимания на это сообщение.',
    'Invite by email' => 'Пригласить с помощью электронной почты',
    'Invite by link' => 'Пригласить по ссылке',
    'Invite new people' => 'Приглашайте новых пользователей',
    'Invited by' => 'Приглашен(ы)',
    'It looks like you clicked on an invalid password reset link. Please try again.' => 'Похоже, вы нажали на недействительную ссылку для сброса пароля. Попробуйте ещё раз.',
    'Language' => 'Язык',
    'Last Login' => 'Последний вход',
    'Mentioning' => 'Упомянут(а)',
    'Missing E-Mail Attribute from AuthClient.' => 'Отсутствует атрибут Email от AuthClient.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Отсутствует атрибут ID AuthClient от AuthClient.',
    'Modules' => 'Модули',
    'My Account' => 'Моя учётная запись',
    'Name' => 'Имя',
    'New password' => 'Новый пароль',
    'No results found!' => 'Результатов не найдено!',
    'No users found.' => 'Пользователи не найдены.',
    'Notifications' => 'Уведомления',
    'Offline' => 'Оффлайн',
    'Online' => 'Онлайн',
    'Password' => 'Пароль',
    'Password changed' => 'Пароль изменен',
    'Password needs to be at least {chars} characters long.' => 'Длина пароля должна быть не менее {chars} символов.',
    'Password recovery' => 'Восстановление пароля',
    'Pending Requests' => 'Текущие запросы',
    'People' => 'Люди',
    'Permission' => 'Разрешение',
    'Profile' => 'Профиль',
    'Profile posts only' => 'Только посты пользователя',
    'Register now and participate!' => 'Зарегистрируйтесь сейчас',
    'Search...' => 'Поиск...',
    'Security' => 'Безопасность',
    'Settings' => 'Настройки',
    'Show At Registration' => 'Показать при Регистрации',
    'Show all content' => 'Показать все содержимое',
    'Sign in' => 'Войти',
    'Sign in / up' => 'Войти / Присоединиться',
    'Sign up' => 'Зарегистрироваться',
    'Sign up now' => 'Зарегистрироваться сейчас',
    'Sort order' => 'Порядок сортировки',
    'Source' => 'Источник',
    'Status' => 'Статус',
    'Tags' => 'Теги',
    'The Group Manager can approve pending registrations of this group.' => 'Менеджер группы может одобрить оставшиеся регистрации этой группы.',
    'The secure link has been copied in your clipboard!' => 'Защищенная ссылка скопирована в буфер обмена!',
    'The user has been blocked for you.' => 'Пользователь был заблокирован для вас.',
    'The user has been unblocked for you.' => 'Пользователь был разблокирован для вас.',
    'Try other keywords or remove filters.' => 'Попробуйте другие ключевые слова или удалите фильтры.',
    'Unblock user' => 'Разблокировать пользователя',
    'Unknown user status!' => 'Неизвестный статус пользователья!',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Ошибок ввода пароля после последнего входа: {failedLoginAttemptsCount}',
    'Updated at' => 'Обновлено',
    'Updated by' => 'Обновлено пользователем',
    'User' => 'Пользователь',
    'User Group' => 'Группа пользователей',
    'User has been invited.' => 'Пользователь был приглашён.',
    'Username' => 'Имя пользователя',
    'Username contains invalid characters.' => 'Имя пользователя содержит недопустимые символы.',
    'View your about page' => 'Просмотр Вашей страницы «Обо мне»',
    'Visibility' => 'Отображение',
    'Visible' => 'Видимо',
    'Welcome to %appName%' => 'Добро пожаловать в %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Добро пожаловать в %appName%. Пожалуйста, нажмите на кнопку ниже, чтобы продолжить регистрацию.',
    'Whenever a user follows another user.' => 'Когда пользователь подписывается на другого пользователя.',
    'You got an invite' => 'Вы получили приглашение',
    'You tried registering an account with %appName%, but already have an account associated with this email address.' => 'Вы пытались зарегистрировать учетную запись в %appName%, но у вас уже есть учётная запись, связанная с этим адресом электронной почты.',
    'You\'re not registered.' => 'Вы не зарегистрированы.',
    'You\'ve been invited to join {space} on {appName}' => 'Вас пригласили присоединиться к сообществу {space} в {appName}',
    'Your account is disabled!' => 'Ваш аккаунт отключен!',
    'Your account is not approved yet!' => 'Ваш аккаунт еще не подтвержден!',
    'Your are already logged in! - Logout first!' => 'Вы уже вошли! - Сначала выйдите из системы!',
    'Your new password must not be equal your current password!' => 'Ваш новый пароль не должен совпадать с Вашим текущим паролем!',
    'invited you to join {name}.' => 'приглашает Вас присоединиться к {name}.',
    'invited you to join {space} on {name}.' => 'приглашает Вас присоединиться к сообществу {space} на {name}',
    'or' => 'или',
    'Empty password cannot be saved!' => '',
];
